#####################################
# FUNCTIONS REQUIRING RETURN VALUES #
#####################################

# ask_y_n
# asks a yes or no question to the user
# $1 - the prompt for the question to ask
# $2 - what should the default be?
# 
# on exit ANSWER must contain either "true"
# or "false"
ask_y_n()
#########
{
    # before we ask the question we append the "default" prompt
    # to the end of the question.. i.e. something like [Y/N]...
    
    if [ "${2:-Y}" = "Y" ] ; then
        _PROMPT="${MSG_PROMPT_YES_NO}"
    else
        _PROMPT="${MSG_PROMPT_NO_YES}"
    fi
    
    echo 
    echo "${1} ${_PROMPT}"
    read ANSWER
    case $ANSWER in
        "${MSG_ANSWER_yes}" | "${MSG_ANSWER_Yes}" | "${MSG_ANSWER_y}" | "${MSG_ANSWER_Y}" )
            ANSWER="true"
            ;;
        * )
            ANSWER="false"
            ;;
    esac
}

# ask_main_option_selection_screen
# Output when a suboption is selected,
# i.e Tools, SCCentral, Documentation, ... to decide what should be installed
#
# NOTE: on exit, CHOICE must contain i.e do not translate :
# "All" - to select all options 
# "None" - to select no options
# "Quit" - to exit setup
# "Start" - to start intalation
ask_main_option_selection_screen()
##################################
{
    echo "${MSG_MAIN_SCREEN_PROMPT_1}"
    echo "${MSG_MAIN_SCREEN_PROMPT_2}"
    echo "${MSG_MAIN_SCREEN_PROMPT_3}"
    echo "${MSG_MAIN_SCREEN_PROMPT_4}"
    echo "${MSG_MAIN_SCREEN_PROMPT_5}"
    echo "${MSG_MAIN_SCREEN_PROMPT_6}"
    echo "${MSG_MAIN_SCREEN_PROMPT_7}"
    echo "${MSG_MAIN_SCREEN_PROMPT_8}"
    
    read JUNK

    case $JUNK in

        "${MSG_MAIN_SCREEN_ANSWER_A}" | "${MSG_MAIN_SCREEN_ANSWER_a}" )
            CHOICE="All"
            ;;
        "${MSG_MAIN_SCREEN_ANSWER_N}" | "${MSG_MAIN_SCREEN_ANSWER_n}" )
            CHOICE="None"
            ;;
        "${MSG_MAIN_SCREEN_ANSWER_Q}" | "${MSG_MAIN_SCREEN_ANSWER_q}" )
            CHOICE="Quit"
            ;;
        "${MSG_MAIN_SCREEN_ANSWER_S}" | "${MSG_MAIN_SCREEN_ANSWER_s}" )
            CHOICE="Start"
            ;;
        * )
            CHOICE="${JUNK}"
            ;;
    esac
}

# ask_suboption_selection_screen
# Output when a suboption is selected,
# i.e Tools, SCCentral, Documentation, ... to decide what should be installed
#
# NOTE: on exit, CHOICE must contain:
# "All" - to select all options
# "None" - to select no options
# "Help" - to show the help
# "Previous" - to go to the previous menu
# "Quit" - to exit setup
ask_suboption_selection_screen()
################################
{
    echo "${MSG_SUBOPTION_SCREEN_PROMPT_1}"
    echo "${MSG_SUBOPTION_SCREEN_PROMPT_2}"
    echo "${MSG_SUBOPTION_SCREEN_PROMPT_3}"
    echo "${MSG_SUBOPTION_SCREEN_PROMPT_4}"
    echo "${MSG_SUBOPTION_SCREEN_PROMPT_5}"
    echo "${MSG_SUBOPTION_SCREEN_PROMPT_6}"
    echo "${MSG_SUBOPTION_SCREEN_PROMPT_7}"
    echo "${MSG_SUBOPTION_SCREEN_PROMPT_8}"
    echo "${MSG_SUBOPTION_SCREEN_PROMPT_9}"
    echo "${MSG_SUBOPTION_SCREEN_PROMPT_10}"

    read JUNK

    case $JUNK in
        
        "${MSG_SUBOPTION_SCREEN_ANSWER_A}" | "${MSG_SUBOPTION_SCREEN_ANSWER_a}" )
            CHOICE="All"
            ;;

        "${MSG_SUBOPTION_SCREEN_ANSWER_N}" | "${MSG_SUBOPTION_SCREEN_ANSWER_n}" )
            CHOICE="None"
            ;;

        "${MSG_SUBOPTION_SCREEN_ANSWER_H}" | "${MSG_SUBOPTION_SCREEN_ANSWER_h}" )
            CHOICE="Help"
            ;;

        "${MSG_SUBOPTION_SCREEN_ANSWER_P}" | "${MSG_SUBOPTION_SCREEN_ANSWER_p}" )
            CHOICE="Previous"
            ;;
        
        "${MSG_SUBOPTION_SCREEN_ANSWER_Q}" | "${MSG_SUBOPTION_SCREEN_ANSWER_q}" )
            CHOICE="Quit"
            ;;

        * )
            CHOICE="${JUNK}"
            ;;

    esac
}

###########################################
# FUNCTIONS REQUIRING STRING SUBSTITUTION #
###########################################

display_msg_need_to_source_for_environment()
############################################
{
    eval "echo \"${MSG_NEED_TO_SOURCE_FOR_ENV_1}\""
    eval "echo \"${MSG_NEED_TO_SOURCE_FOR_ENV_2}\""
    eval "echo \"${MSG_NEED_TO_SOURCE_FOR_ENV_3}\""
    eval "echo \"${MSG_NEED_TO_SOURCE_FOR_ENV_4}\""
    eval "echo \"${MSG_NEED_TO_SOURCE_FOR_ENV_5}\""
}

display_msg_installing_files_into()
###################################
{
    eval "echo \"${MSG_INSTALLING_FILES_INTO}\""
}

display_msg_installing_a_file_into()
####################################
{
    eval "echo \"${MSG_INSTALLING_A_FILE_INTO}\""
}

display_error_extracting_files()
################################
{
    eval "echo \"${MSG_ERROR_EXTRACTING_FILES_1}\""
    eval "echo \"${MSG_ERROR_EXTRACTING_FILES_2}\""
    eval "echo \"${MSG_ERROR_EXTRACTING_FILES_3}\""
}

display_prompt_file_exists_overwrite()
######################################
{
    eval "echo \"${MSG_PROMPT_FILE_EXISTS_OVERWRITE}\""
}

display_prompt_file_exists_overwrite_ok_to_skip()
#################################################
{
    eval "echo \"${MSG_PROMPT_FILE_EXISTS_OVERWRITE_OK_TO_SKIP_1}\""
    eval "echo \"${MSG_PROMPT_FILE_EXISTS_OVERWRITE_OK_TO_SKIP_2}\""
    eval "echo \"${MSG_PROMPT_FILE_EXISTS_OVERWRITE_OK_TO_SKIP_3}\""
}

display_msg_skipped_creating_file()
###################################
{
    eval "echo \"${MSG_SKIPPED_CREATING_FILE}\""
}

display_msg_extracted_files_location()
######################################
{
    eval "echo \"${MSG_EXTRACTED_FILES_LOCATION_1}\""
    eval "echo \"${MSG_EXTRACTED_FILES_LOCATION_2}\""
}

#
# $1: filename
#
display_header()
################
{
    cat <<-EOF  >> "$1"
echo ${MSG_HEADER_1}
echo ${MSG_HEADER_2}
echo ${MSG_HEADER_3}
echo 
EOF
}

display_default_install_directory()
###################################
{
    eval "echo"
    eval "echo \"${MSG_DEFAULT_INSTALL_DIRECTORY_1}\""
    eval "echo \"${MSG_DEFAULT_INSTALL_DIRECTORY_2}\""
}

display_current_install_directory()
###################################
{
    eval "echo"
    eval "echo \"${MSG_CURRENT_INSTALL_DIRECTORY_1}\""
    eval "echo \"${MSG_CURRENT_INSTALL_DIRECTORY_2}\""
}

display_error_os_version_too_low()
##################################
{
    eval "echo \"${MSG_ERROR_OS_VERSION_TOO_LOW_1}\""
    eval "echo \"${MSG_ERROR_OS_VERSION_TOO_LOW_2}\""
    eval "echo \"${MSG_ERROR_OS_VERSION_TOO_LOW_3}\""
    eval "echo \"${MSG_ERROR_OS_VERSION_TOO_LOW_4}\""
    eval "echo \"${MSG_ERROR_OS_VERSION_TOO_LOW_5}\""
    eval "echo \"${MSG_ERROR_OS_VERSION_TOO_LOW_6}\""
    eval "echo \"${MSG_ERROR_OS_VERSION_TOO_LOW_7}\""
    eval "echo \"${MSG_ERROR_OS_VERSION_TOO_LOW_8}\""
    eval "echo \"${MSG_ERROR_OS_VERSION_TOO_LOW_9}\""
}

display_error_version_mismatch()
################################
{
    eval "echo"
    eval "echo \"${MSG_ERROR_VERSION_MISMATCH_1}\""
    eval "echo \"${MSG_ERROR_VERSION_MISMATCH_2}\""
    eval "echo \"${MSG_ERROR_VERSION_MISMATCH_3}\""
}

display_error_need_df()
#######################
{
    eval "echo"
    eval "echo \"${MSG_ERROR_NEED_DF_1}\""
    eval "echo \"${MSG_ERROR_NEED_DF_2}\""
}

display_error_need_tar()
########################
{
    eval "echo"
    eval "echo \"${MSG_ERROR_NEED_TAR_1}\""
    eval "echo \"${MSG_ERROR_NEED_TAR_2}\""
}

display_error_not_a_directory()
###############################
{
    eval "echo \"${MSG_ERROR_NOT_A_DIRECTORY}\""
}

display_error_invalid_directory()
#################################
{
    eval "echo \"${MSG_ERROR_INVALID_DIRECTORY}\""
}

display_msg_directory_already_exists()
######################################
{
    eval "echo \"${MSG_DIRECTORY_ALREADY_EXISTS}\""
}

display_msg_directory_does_not_exist()
######################################
{
    eval "echo \"${MSG_DIRECTORY_DOES_NOT_EXIST}\""
}

display_error_cannot_create_directory()
#######################################
{
    eval "echo \"${MSG_ERROR_CANNOT_CREATE_DIRECTORY}\""
}

display_error_cannot_create_directory_aborting()
################################################
{
    eval "echo \"${MSG_ERROR_CANNOT_CREATE_DIRECTORY_ABORTING}\""
}

err_dont_have_write_permissions()
#################################
{
    eval "echo \"${MSG_ERR_DONT_HAVE_WRITE_PERMISSIONS}\""
}

display_msg_finished_installing()
#################################
{
    eval "echo \"${MSG_FINISHED_INSTALLING}\""
}

display_error_disagree_license()
################################
{
    eval "echo \"${MSG_ERROR_DISAGREE_LICENSE_1}\""
    eval "echo \"${MSG_ERROR_DISAGREE_LICENSE_2}\""
}

display_how_many_selected()
###########################
{
    eval "echo \"${MSG_HOW_MANY_SELECTED}\""
}

display_error_invalid_option()
##############################
{
    eval "echo \"${MSG_ERROR_INVALID_OPTION}\""
}

display_error_unknown_option()
##############################
{
    eval "echo \"${MSG_ERROR_UNKNOWN_OPTION}\""
}

display_error_cl_options_unknown_argument()
###########################################
{
    eval "echo \"${MSG_ERROR_CL_OPTIONS_UNKNOWN_ARGUMENT}\""
}

display_error_unknown_region()
##############################
{
    eval "echo \"${MSG_ERROR_UNKNOWN_REGION}\""
}

display_error_internal_error()
##############################
{
    eval "echo \"${MSG_ERROR_INTERNAL_ERROR}\""
}

display_error_setup_internal_error_1()
######################################
{
    eval "echo \"${MSG_ERROR_SETUP_INTERNAL_ERROR_1_1}\""
    eval "echo \"${MSG_ERROR_SETUP_INTERNAL_ERROR_1_2}\""
}

display_error_setup_internal_error_num()
########################################
{
    eval "echo \"${MSG_ERROR_SETUP_INTERNAL_ERROR_NUM_1}\""
    eval "echo \"${MSG_ERROR_SETUP_INTERNAL_ERROR_NUM_2}\""
}

display_error_insufficient_disk_space()
#######################################
{
    eval "echo \"${MSG_ERROR_INSUFFICIENT_DISK_SPACE}\""
}

display_msg_sufficient_disk_space()
###################################
{
    eval "echo \"${MSG_SUFFICIENT_DISK_SPACE}\""
}

display_msg_ask_number_of_licenses()
####################################
{
    eval "echo \"${MSG_ASK_NUMBER_OF_LICENSES}\""
}

display_error_corrupt_ticfile()
###############################
{
    eval "echo \"${MSG_ERROR_CORRUPT_TICFILE_1}\""
    eval "echo \"${MSG_ERROR_CORRUPT_TICFILE_2}\""
}

###############################################
# FUNCTIONS REPRESENTING LARGE BLOCKS OF TEXT #
###############################################

display_msg_rename_suffix()
###########################
{
    echo "${MSG_RENAME_SUFFIX_1}"
    echo "${MSG_RENAME_SUFFIX_2}"
    echo "${MSG_RENAME_SUFFIX_3}"
    echo "${MSG_RENAME_SUFFIX_4}"
}

display_msg_starting_install()
##############################
{
    echo 
    echo "${MSG_STARTING_INSTALL_1}"
    echo 
    echo "${MSG_STARTING_INSTALL_2}"
}

display_msg_install_completed()
###############################
{
    echo 
    echo "${MSG_INSTALL_COMPLETED_1}"
    echo 
    echo "${MSG_INSTALL_COMPLETED_2}"
    echo 
}

display_welcome_message()
#########################
{
    eval "echo \"${MSG_WELCOME_MESSAGE_1}\""
    echo
    eval "echo \"${MSG_WELCOME_MESSAGE_2}\""
    echo "${MSG_WELCOME_MESSAGE_3}"
    echo
    echo "${MSG_WELCOME_MESSAGE_4}"
    echo
    echo "${MSG_WELCOME_MESSAGE_5}"
    echo "${MSG_WELCOME_MESSAGE_6}"
    echo "${MSG_WELCOME_MESSAGE_7}"
    echo
}

display_welcome_install_key()
#############################
{
    echo "${MSG_WELCOME_INSTALL_KEY_1}"
    echo "${MSG_WELCOME_INSTALL_KEY_2}"
    echo "${MSG_WELCOME_INSTALL_KEY_3}"
    echo "${MSG_WELCOME_INSTALL_KEY_4}"
    echo "${MSG_WELCOME_INSTALL_KEY_5}"
    echo "${MSG_WELCOME_INSTALL_KEY_6}"
    echo "${MSG_WELCOME_INSTALL_KEY_7}"
}

display_welcome_license_agreement()
###################################
{
    echo "${MSG_WELCOME_LICENSE_AGREEMENT_1}"
    echo "${MSG_WELCOME_LICENSE_AGREEMENT_2}"
}

display_license_country_list()
##############################
{
    echo "${MSG_LICENSE_COUNTRY_LIST_1}"
    echo "${MSG_LICENSE_COUNTRY_LIST_2}"
    echo "${MSG_LICENSE_COUNTRY_LIST_3}"
    echo "${MSG_LICENSE_COUNTRY_LIST_4}"
    echo "${MSG_LICENSE_COUNTRY_LIST_5}"
    echo "${MSG_LICENSE_COUNTRY_LIST_6}"
    echo "${MSG_LICENSE_COUNTRY_LIST_7}"
    echo "${MSG_LICENSE_COUNTRY_LIST_8}"
    echo "${MSG_LICENSE_COUNTRY_LIST_9}"
    echo "${MSG_LICENSE_COUNTRY_LIST_10}"
    echo "${MSG_LICENSE_COUNTRY_LIST_11}"
    echo "${MSG_LICENSE_COUNTRY_LIST_12}"
    echo "${MSG_LICENSE_COUNTRY_LIST_13}"
    echo "${MSG_LICENSE_COUNTRY_LIST_14}"
    echo "${MSG_LICENSE_COUNTRY_LIST_15}"
    echo "${MSG_LICENSE_COUNTRY_LIST_16}"
    echo "${MSG_LICENSE_COUNTRY_LIST_17}"
    echo "${MSG_LICENSE_COUNTRY_LIST_18}"
    echo "${MSG_LICENSE_COUNTRY_LIST_19}"
    echo "${MSG_LICENSE_COUNTRY_LIST_20}"
    echo "${MSG_LICENSE_COUNTRY_LIST_21}"
    echo "${MSG_LICENSE_COUNTRY_LIST_22}"
}

display_msg_no_options_selected()
#################################
{
    echo  
    echo "${MSG_NO_OPTIONS_SELECTED_1}"
    echo "${MSG_NO_OPTIONS_SELECTED_2}"
    echo 
}

display_tools_option_help()
###########################
{
    clear
    echo "${MSG_TOOLS_OPTION_HELP_1}"
    echo
    echo "${MSG_TOOLS_OPTION_HELP_2}"
    echo
    echo "${MSG_TOOLS_OPTION_HELP_3}"
    echo
    echo "${MSG_TOOLS_OPTION_HELP_4}"
    echo
    echo "${MSG_TOOLS_OPTION_HELP_5}"
    echo
    echo "${MSG_TOOLS_OPTION_HELP_6}"
    echo
    echo "${MSG_TOOLS_OPTION_HELP_7}"
    echo "${MSG_TOOLS_OPTION_HELP_8}"
    echo
}

display_sccentral_option_help()
###############################
{
    clear
    echo "${MSG_SCCENTRAL_OPTION_HELP_1}"
    echo
    echo "${MSG_SCCENTRAL_OPTION_HELP_2}"
    echo
    echo "${MSG_SCCENTRAL_OPTION_HELP_3}"
    echo
    echo "${MSG_SCCENTRAL_OPTION_HELP_4}"
    echo "${MSG_SCCENTRAL_OPTION_HELP_5}"
    echo
}

display_documentation_option_help()
###################################
{
    clear
    echo "${MSG_DOCUMENTATION_OPTION_HELP_1}"
    echo
    echo "${MSG_DOCUMENTATION_OPTION_HELP_2}"
    echo
    echo "${MSG_DOCUMENTATION_OPTION_HELP_3}"
    echo "${MSG_DOCUMENTATION_OPTION_HELP_4}"
    echo
}

display_synchronization_option_help()
#####################################
{
    clear
    echo "${MSG_SYNCHRONIZATION_OPTION_HELP_1}"
    echo "${MSG_SYNCHRONIZATION_OPTION_HELP_2}"
    echo
    echo "${MSG_SYNCHRONIZATION_OPTION_HELP_3}"
    echo "${MSG_SYNCHRONIZATION_OPTION_HELP_4}"
    echo
    echo "${MSG_SYNCHRONIZATION_OPTION_HELP_5}"
    echo "${MSG_SYNCHRONIZATION_OPTION_HELP_6}"
    echo
    echo "${MSG_SYNCHRONIZATION_OPTION_HELP_7}"
    echo
    echo "${MSG_SYNCHRONIZATION_OPTION_HELP_8}"
    echo
    echo "${MSG_SYNCHRONIZATION_OPTION_HELP_9}"
    echo "${MSG_SYNCHRONIZATION_OPTION_HELP_10}"
    echo
    echo "${MSG_SYNCHRONIZATION_OPTION_HELP_1}"
    echo "${MSG_SYNCHRONIZATION_OPTION_HELP_12}"
    echo
    echo "${MSG_SYNCHRONIZATION_OPTION_HELP_13}"
    echo
    echo "${MSG_SYNCHRONIZATION_OPTION_HELP_14}"
    echo "${MSG_SYNCHRONIZATION_OPTION_HELP_15}"
    echo
}

display_database_options_help()
###############################
{
    clear
    echo "${MSG_DATABASE_OPTIONS_HELP_1}"
    echo "${MSG_DATABASE_OPTIONS_HELP_2}"
    echo
    echo "${MSG_DATABASE_OPTIONS_HELP_3}"
    echo
    echo "${MSG_DATABASE_OPTIONS_HELP_4}"
    echo "${MSG_DATABASE_OPTIONS_HELP_5}"
    echo
    echo "${MSG_DATABASE_OPTIONS_HELP_6}"
    echo "${MSG_DATABASE_OPTIONS_HELP_7}"
    echo
    echo "${MSG_DATABASE_OPTIONS_HELP_8}"
    echo "${MSG_DATABASE_OPTIONS_HELP_9}"
    echo
    echo "${MSG_DATABASE_OPTIONS_HELP_10}"
    echo
    echo "${MSG_DATABASE_OPTIONS_HELP_11}"
    echo "${MSG_DATABASE_OPTIONS_HELP_12}"
    echo
    echo "${MSG_DATABASE_OPTIONS_HELP_13}"
    echo
    echo "${MSG_DATABASE_OPTIONS_HELP_14}"
    echo
    echo "${MSG_DATABASE_OPTIONS_HELP_15}"
    echo "${MSG_DATABASE_OPTIONS_HELP_16}"
    echo
}

display_interactive_mode_help()
###############################
{
    echo "${MSG_INTERACTIVE_MODE_HELP_1}"
    echo 
    echo "${MSG_INTERACTIVE_MODE_HELP_2}"
    echo
    echo "${MSG_INTERACTIVE_MODE_HELP_3}"
    echo "${MSG_INTERACTIVE_MODE_HELP_4}"
    echo "${MSG_INTERACTIVE_MODE_HELP_5}"
    echo "${MSG_INTERACTIVE_MODE_HELP_6}"
    echo "${MSG_INTERACTIVE_MODE_HELP_7}"
    echo "${MSG_INTERACTIVE_MODE_HELP_8}"
    echo "${MSG_INTERACTIVE_MODE_HELP_9}"
    echo "${MSG_INTERACTIVE_MODE_HELP_10}"
    echo 
    echo "${MSG_INTERACTIVE_MODE_HELP_11}"
    echo "${MSG_INTERACTIVE_MODE_HELP_12}"
    echo "${MSG_INTERACTIVE_MODE_HELP_13}"
    echo "${MSG_INTERACTIVE_MODE_HELP_14}"
    echo "${MSG_INTERACTIVE_MODE_HELP_15}"
    echo "${MSG_INTERACTIVE_MODE_HELP_16}"
    echo "${MSG_INTERACTIVE_MODE_HELP_17}"
    echo "${MSG_INTERACTIVE_MODE_HELP_18}"
    echo "${MSG_INTERACTIVE_MODE_HELP_19}"
    echo "${MSG_INTERACTIVE_MODE_HELP_20}"
    echo "${MSG_INTERACTIVE_MODE_HELP_21}"
}

display_cl_options_help()
#########################
{
    echo "${MSG_CL_OPTIONS_HELP_1}"
    echo
    echo "${MSG_CL_OPTIONS_HELP_2}"
    echo "${MSG_CL_OPTIONS_HELP_3}"
    echo "${MSG_CL_OPTIONS_HELP_4}"
    echo "${MSG_CL_OPTIONS_HELP_5}"
    echo "${MSG_CL_OPTIONS_HELP_6}"
    echo "${MSG_CL_OPTIONS_HELP_7}"
    echo "${MSG_CL_OPTIONS_HELP_8}"
    echo "${MSG_CL_OPTIONS_HELP_9}"
    echo "${MSG_CL_OPTIONS_HELP_10}"
    echo
    echo "${MSG_CL_OPTIONS_HELP_11}"
    echo "${MSG_CL_OPTIONS_HELP_12}"
    echo "${MSG_CL_OPTIONS_HELP_13}"
    echo "${MSG_CL_OPTIONS_HELP_14}"
    echo "${MSG_CL_OPTIONS_HELP_15}"
    echo "${MSG_CL_OPTIONS_HELP_16}"
    echo "${MSG_CL_OPTIONS_HELP_17}"
    echo "${MSG_CL_OPTIONS_HELP_18}"
    echo
    echo "${MSG_CL_OPTIONS_HELP_19}"
    echo "${MSG_CL_OPTIONS_HELP_20}"
    echo "${MSG_CL_OPTIONS_HELP_21}"
    echo "${MSG_CL_OPTIONS_HELP_22}"
    echo "${MSG_CL_OPTIONS_HELP_23}"
    echo "${MSG_CL_OPTIONS_HELP_24}"
    echo "${MSG_CL_OPTIONS_HELP_25}"
}

display_cl_options_usage()
##########################
{
    eval "echo \"${MSG_CL_OPTIONS_USAGE_1}\""
    echo 
    echo "${MSG_CL_OPTIONS_USAGE_2}"
    echo "${MSG_CL_OPTIONS_USAGE_3}"
    echo "${MSG_CL_OPTIONS_USAGE_4}"
    echo "${MSG_CL_OPTIONS_USAGE_5}"
    echo "${MSG_CL_OPTIONS_USAGE_6}"
    echo "${MSG_CL_OPTIONS_USAGE_7}"
    echo "${MSG_CL_OPTIONS_USAGE_8}"
    echo "${MSG_CL_OPTIONS_USAGE_9}"
    echo "${MSG_CL_OPTIONS_USAGE_10}"
    echo "${MSG_CL_OPTIONS_USAGE_11}"
    echo "${MSG_CL_OPTIONS_USAGE_12}"
    echo "${MSG_CL_OPTIONS_USAGE_13}"
    echo "${MSG_CL_OPTIONS_USAGE_14}"
    echo "${MSG_CL_OPTIONS_USAGE_15}"
    echo "${MSG_CL_OPTIONS_USAGE_16}"
    echo "${MSG_CL_OPTIONS_USAGE_17}"
    echo "${MSG_CL_OPTIONS_USAGE_18}"
}
